package com.timtech.profile.util;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.springframework.http.HttpStatus;

import com.timtech.profile.dto.ProfileDto;
import com.timtech.profile.exception.BusinessException;

import lombok.Builder;

@Builder
public class Utils {

	public boolean isValidPanCard(String panCardNo) {

		String regex = "[A-Z]{5}[0-9]{4}[A-Z]{1}";

		Pattern p = Pattern.compile(regex);

		if (panCardNo == null) {
			return false;
		}

		Matcher m = p.matcher(panCardNo);

		return m.matches();
	}

	public boolean isValidAadhar(String adhar) {

		String regex = "[1-9]{12}";

		Pattern p = Pattern.compile(regex);

		if (adhar == null) {
			return false;
		}

		Matcher m = p.matcher(adhar);

		return m.matches();
	}

	public boolean isMobileValidFormat(String mobile) {

		String regex = "[6-9]{1}[0-9]{9}";

		Pattern p = Pattern.compile(regex);

		if (mobile == null) {
			return false;
		}

		Matcher m = p.matcher(mobile);

		return m.matches();
	}
	
	public boolean isNameValidFormat(String name) {

		String regex = "^[A-Za-z]+( [A-Za-z]+)?$";

		Pattern p = Pattern.compile(regex);

		if (name == null) {
			return false;
		}

		Matcher m = p.matcher(name);

		return m.matches();
	}
	
	public boolean isDOBValidFormat(String dob) {
		
        String regex = "^(0[1-9]|1[0-2])-(0[1-9]|[12][0-9]|3[01])-(\\d{4})$";

        Pattern p = Pattern.compile(regex);

        if (dob == null) {
            return false;
        }

        Matcher m = p.matcher(dob);

        return m.matches();
    }
	
	
	public boolean isValidDataFormats(ProfileDto profileDto) {

	    List<String> validationErrors = new ArrayList<>();

	    if (!isValidPanCard(profileDto.getPermanentAccountNumber())) {
	        validationErrors.add("Invalid PAN");
	    }

	    if (!isValidAadhar(profileDto.getAdharNumber())) {
	        validationErrors.add("Invalid Aadhar Number");
	    }

	    if (!isDOBValidFormat(profileDto.getDateOfBirth())) {
	        validationErrors.add("Invalid Date of Birth");
	    }

	    if (!isNameValidFormat(profileDto.getFirstName())) {
	        validationErrors.add("Invalid First Name");
	    }

	    if (!isNameValidFormat(profileDto.getLastName())) {
	        validationErrors.add("Invalid Last Name");
	    }

	    if (!isMobileValidFormat(profileDto.getMobileNumber())) {
	        validationErrors.add("Invalid Mobile Number");
	    }

	    if (validationErrors.isEmpty()) {
	        return true;
	    } else {
	        throw new BusinessException(HttpStatus.BAD_REQUEST,
	                "Validation errors: " + String.join(", ", validationErrors));
	    }

	}

}
